@@ -1,6 +1,6 @@
 __title__ = 'pyflix2'
-__version__ = '0.1.1'
-__build__ = 0x001300
+__version__ = '0.1.2'
+__build__ = __version__
 __author__ = 'Arup Malakar'
 __license__ = 'BSD'
 __copyright__ = 'Copyright 2012 Arup Malakar'
